Depreciated function that is only used to transform older raw data. The measurement script was changed relatively early. However, some measurements may still depend on this function.
1 |
df |
Data frame containing raw time data from measurement script |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.